import { Attachment } from '../model/attachment';
import { Category } from '../model/category';
import { Comment } from '../model/comment';
import { Menu } from '../model/menu';
import { MenuData } from '../model/menuData';
import { MenuLocation } from '../model/menuLocation';
import { MenuLocationData } from '../model/menuLocationData';
import { Page } from '../model/page';
import { PageRevision } from '../model/pageRevision';
import { Post } from '../model/post';
import { PostRevision } from '../model/postRevision';
import { RenderedBlock } from '../model/renderedBlock';
import { SearchResult } from '../model/searchResult';
import { Settings } from '../model/settings';
import { Status } from '../model/status';
import { Tag } from '../model/tag';
import { Taxonomy } from '../model/taxonomy';
import { Theme } from '../model/theme';
import { Type } from '../model/type';
import { User } from '../model/user';
import { WpBlock } from '../model/wpBlock';
import { WpBlockRevision } from '../model/wpBlockRevision';
import * as URI from "urijs";
import { ApiUtils } from "./api";

export class DefaultService {

  private rptToken: string;
  private token: string;
  private basePath: string;

  constructor(basePath: string, token: string) {
    this.token = token;
    this.basePath = basePath;
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param force Whether to bypass trash and force deletion.
  */
  public async deleteWpV2BlocksById(opts?: { id: string, id2?: number, force?: boolean, }):Promise<WpBlock> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the term.
   * @param force Required to be true, as terms do not support trashing.
  */
  public async deleteWpV2CategoriesById(opts?: { id: string, id2?: number, force?: boolean, }):Promise<Category> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param force Whether to bypass trash and force deletion.
   * @param password The password for the parent post of the comment (if the post is password protected).
  */
  public async deleteWpV2CommentsById(opts?: { id: string, id2?: number, force?: boolean, password?: string, }):Promise<Comment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    if (opts.password !== undefined && opts.password !== null) {
        uri.addQuery('password', <any>opts.password);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param force Whether to bypass trash and force deletion.
  */
  public async deleteWpV2MediaById(opts?: { id: string, id2?: number, force?: boolean, }):Promise<Attachment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param force Whether to bypass trash and force deletion.
  */
  public async deleteWpV2PagesById(opts?: { id: string, id2?: number, force?: boolean, }):Promise<Page> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 Unique identifier for the object.
   * @param force Required to be true, as revisions do not support trashing.
  */
  public async deleteWpV2PagesByParentRevisionsById(opts?: { parent: string, id: string, parent2?: number, id2?: number, force?: boolean, }):Promise<PageRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param force Whether to bypass trash and force deletion.
  */
  public async deleteWpV2PostsById(opts?: { id: string, id2?: number, force?: boolean, }):Promise<Post> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 Unique identifier for the object.
   * @param force Required to be true, as revisions do not support trashing.
  */
  public async deleteWpV2PostsByParentRevisionsById(opts?: { parent: string, id: string, parent2?: number, id2?: number, force?: boolean, }):Promise<PostRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the term.
   * @param force Required to be true, as terms do not support trashing.
  */
  public async deleteWpV2TagsById(opts?: { id: string, id2?: number, force?: boolean, }):Promise<Tag> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param reassign Reassign the deleted user&#39;s posts and links to this user ID.
   * @param id2 Unique identifier for the user.
   * @param force Required to be true, as users do not support trashing.
  */
  public async deleteWpV2UsersById(opts?: { id: string, reassign: number, id2?: number, force?: boolean, }):Promise<User> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    if (opts.reassign !== undefined && opts.reassign !== null) {
        uri.addQuery('reassign', <any>opts.reassign);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param reassign Reassign the deleted user&#39;s posts and links to this user ID.
   * @param force Required to be true, as users do not support trashing.
  */
  public async deleteWpV2UsersMe(opts?: { reassign: number, force?: boolean, }):Promise<User> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.force !== undefined && opts.force !== null) {
        uri.addQuery('force', <any>opts.force);
    }
    if (opts.reassign !== undefined && opts.reassign !== null) {
        uri.addQuery('reassign', <any>opts.reassign);
    }
    const options = {
      method: "delete",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
  */
  public async getMenusV1Locations(opts?: { }):Promise<Array<MenuLocation>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
  */
  public async getMenusV1LocationsById(opts?: { id: string, }):Promise<MenuLocationData> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
  */
  public async getMenusV1Menus(opts?: { }):Promise<Array<Menu>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
  */
  public async getMenusV1MenusById(opts?: { id: string, }):Promise<MenuData> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param name 
   * @param name2 Unique registered name for the block.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param attributes Attributes for core/tag-cloud block
   * @param postId ID of the post context.
  */
  public async getWpV2BlockRendererByName(opts?: { name: string, name2?: string, context?: string, attributes?: string, postId?: number, }):Promise<RenderedBlock> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.name2 !== undefined && opts.name2 !== null) {
        uri.addQuery('name', <any>opts.name2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.attributes !== undefined && opts.attributes !== null) {
        uri.addQuery('attributes', <any>opts.attributes);
    }
    if (opts.postId !== undefined && opts.postId !== null) {
        uri.addQuery('post_id', <any>opts.postId);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param after Limit response to posts published after a given ISO8601 compliant date.
   * @param before Limit response to posts published before a given ISO8601 compliant date.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
   * @param slug Limit result set to posts with one or more specific slugs.
   * @param status Limit result set to posts assigned one or more statuses.
  */
  public async getWpV2Blocks(opts?: { context?: string, page?: number, perPage?: number, search?: string, after?: Date, before?: Date, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, slug?: Array<string>, status?: Array<string>, }):Promise<Array<WpBlock>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.after !== undefined && opts.after !== null) {
        uri.addQuery('after', <any>opts.after.toISOString());
    }
    if (opts.before !== undefined && opts.before !== null) {
        uri.addQuery('before', <any>opts.before.toISOString());
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    if (opts.status) {
        opts.status.forEach((element) => {
          uri.addQuery('status', <any>element);
        })
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param password The password for the post if it is password protected.
  */
  public async getWpV2BlocksById(opts?: { id: string, id2?: number, context?: string, password?: string, }):Promise<WpBlock> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.password !== undefined && opts.password !== null) {
        uri.addQuery('password', <any>opts.password);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param parent The ID for the parent of the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2BlocksByIdAutosaves(opts?: { id: string, parent?: number, context?: string, }):Promise<Array<WpBlockRevision>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent !== undefined && opts.parent !== null) {
        uri.addQuery('parent', <any>opts.parent);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 The ID for the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2BlocksByParentAutosavesById(opts?: { parent: string, id: string, parent2?: number, id2?: number, context?: string, }):Promise<WpBlockRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by term attribute.
   * @param hideEmpty Whether to hide terms not assigned to any posts.
   * @param parent Limit result set to terms assigned to a specific parent.
   * @param post Limit result set to terms assigned to a specific post.
   * @param slug Limit result set to terms with one or more specific slugs.
  */
  public async getWpV2Categories(opts?: { context?: string, page?: number, perPage?: number, search?: string, exclude?: Array<string>, include?: Array<string>, order?: string, orderby?: string, hideEmpty?: boolean, parent?: number, post?: number, slug?: Array<string>, }):Promise<Array<Category>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.hideEmpty !== undefined && opts.hideEmpty !== null) {
        uri.addQuery('hide_empty', <any>opts.hideEmpty);
    }
    if (opts.parent !== undefined && opts.parent !== null) {
        uri.addQuery('parent', <any>opts.parent);
    }
    if (opts.post !== undefined && opts.post !== null) {
        uri.addQuery('post', <any>opts.post);
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the term.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2CategoriesById(opts?: { id: string, id2?: number, context?: string, }):Promise<Category> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param after Limit response to comments published after a given ISO8601 compliant date.
   * @param author Limit result set to comments assigned to specific user IDs. Requires authorization.
   * @param authorExclude Ensure result set excludes comments assigned to specific user IDs. Requires authorization.
   * @param authorEmail Limit result set to that from a specific author email. Requires authorization.
   * @param before Limit response to comments published before a given ISO8601 compliant date.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
   * @param parent Limit result set to comments of specific parent IDs.
   * @param parentExclude Ensure result set excludes specific parent IDs.
   * @param post Limit result set to comments assigned to specific post IDs.
   * @param status Limit result set to comments assigned a specific status. Requires authorization.
   * @param type Limit result set to comments assigned a specific type. Requires authorization.
   * @param password The password for the post if it is password protected.
  */
  public async getWpV2Comments(opts?: { context?: string, page?: number, perPage?: number, search?: string, after?: Date, author?: Array<string>, authorExclude?: Array<string>, authorEmail?: string, before?: Date, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, parent?: Array<string>, parentExclude?: Array<string>, post?: Array<string>, status?: string, type?: string, password?: string, }):Promise<Array<Comment>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.after !== undefined && opts.after !== null) {
        uri.addQuery('after', <any>opts.after.toISOString());
    }
    if (opts.author) {
        opts.author.forEach((element) => {
          uri.addQuery('author', <any>element);
        })
    }
    if (opts.authorExclude) {
        opts.authorExclude.forEach((element) => {
          uri.addQuery('author_exclude', <any>element);
        })
    }
    if (opts.authorEmail !== undefined && opts.authorEmail !== null) {
        uri.addQuery('author_email', <any>opts.authorEmail);
    }
    if (opts.before !== undefined && opts.before !== null) {
        uri.addQuery('before', <any>opts.before.toISOString());
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.parent) {
        opts.parent.forEach((element) => {
          uri.addQuery('parent', <any>element);
        })
    }
    if (opts.parentExclude) {
        opts.parentExclude.forEach((element) => {
          uri.addQuery('parent_exclude', <any>element);
        })
    }
    if (opts.post) {
        opts.post.forEach((element) => {
          uri.addQuery('post', <any>element);
        })
    }
    if (opts.status !== undefined && opts.status !== null) {
        uri.addQuery('status', <any>opts.status);
    }
    if (opts.type !== undefined && opts.type !== null) {
        uri.addQuery('type', <any>opts.type);
    }
    if (opts.password !== undefined && opts.password !== null) {
        uri.addQuery('password', <any>opts.password);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param password The password for the parent post of the comment (if the post is password protected).
  */
  public async getWpV2CommentsById(opts?: { id: string, id2?: number, context?: string, password?: string, }):Promise<Comment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.password !== undefined && opts.password !== null) {
        uri.addQuery('password', <any>opts.password);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param after Limit response to posts published after a given ISO8601 compliant date.
   * @param author Limit result set to posts assigned to specific authors.
   * @param authorExclude Ensure result set excludes posts assigned to specific authors.
   * @param before Limit response to posts published before a given ISO8601 compliant date.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
   * @param parent Limit result set to items with particular parent IDs.
   * @param parentExclude Limit result set to all items except those of a particular parent ID.
   * @param slug Limit result set to posts with one or more specific slugs.
   * @param status Limit result set to posts assigned one or more statuses.
   * @param mediaType Limit result set to attachments of a particular media type.
   * @param mimeType Limit result set to attachments of a particular MIME type.
  */
  public async getWpV2Media(opts?: { context?: string, page?: number, perPage?: number, search?: string, after?: Date, author?: Array<string>, authorExclude?: Array<string>, before?: Date, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, parent?: Array<string>, parentExclude?: Array<string>, slug?: Array<string>, status?: Array<string>, mediaType?: string, mimeType?: string, }):Promise<Array<Attachment>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.after !== undefined && opts.after !== null) {
        uri.addQuery('after', <any>opts.after.toISOString());
    }
    if (opts.author) {
        opts.author.forEach((element) => {
          uri.addQuery('author', <any>element);
        })
    }
    if (opts.authorExclude) {
        opts.authorExclude.forEach((element) => {
          uri.addQuery('author_exclude', <any>element);
        })
    }
    if (opts.before !== undefined && opts.before !== null) {
        uri.addQuery('before', <any>opts.before.toISOString());
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.parent) {
        opts.parent.forEach((element) => {
          uri.addQuery('parent', <any>element);
        })
    }
    if (opts.parentExclude) {
        opts.parentExclude.forEach((element) => {
          uri.addQuery('parent_exclude', <any>element);
        })
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    if (opts.status) {
        opts.status.forEach((element) => {
          uri.addQuery('status', <any>element);
        })
    }
    if (opts.mediaType !== undefined && opts.mediaType !== null) {
        uri.addQuery('media_type', <any>opts.mediaType);
    }
    if (opts.mimeType !== undefined && opts.mimeType !== null) {
        uri.addQuery('mime_type', <any>opts.mimeType);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2MediaById(opts?: { id: string, id2?: number, context?: string, }):Promise<Attachment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param after Limit response to posts published after a given ISO8601 compliant date.
   * @param author Limit result set to posts assigned to specific authors.
   * @param authorExclude Ensure result set excludes posts assigned to specific authors.
   * @param before Limit response to posts published before a given ISO8601 compliant date.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param menuOrder Limit result set to posts with a specific menu_order value.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
   * @param parent Limit result set to items with particular parent IDs.
   * @param parentExclude Limit result set to all items except those of a particular parent ID.
   * @param slug Limit result set to posts with one or more specific slugs.
   * @param status Limit result set to posts assigned one or more statuses.
  */
  public async getWpV2Pages(opts?: { context?: string, page?: number, perPage?: number, search?: string, after?: Date, author?: Array<string>, authorExclude?: Array<string>, before?: Date, exclude?: Array<string>, include?: Array<string>, menuOrder?: number, offset?: number, order?: string, orderby?: string, parent?: Array<string>, parentExclude?: Array<string>, slug?: Array<string>, status?: Array<string>, }):Promise<Array<Page>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.after !== undefined && opts.after !== null) {
        uri.addQuery('after', <any>opts.after.toISOString());
    }
    if (opts.author) {
        opts.author.forEach((element) => {
          uri.addQuery('author', <any>element);
        })
    }
    if (opts.authorExclude) {
        opts.authorExclude.forEach((element) => {
          uri.addQuery('author_exclude', <any>element);
        })
    }
    if (opts.before !== undefined && opts.before !== null) {
        uri.addQuery('before', <any>opts.before.toISOString());
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.menuOrder !== undefined && opts.menuOrder !== null) {
        uri.addQuery('menu_order', <any>opts.menuOrder);
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.parent) {
        opts.parent.forEach((element) => {
          uri.addQuery('parent', <any>element);
        })
    }
    if (opts.parentExclude) {
        opts.parentExclude.forEach((element) => {
          uri.addQuery('parent_exclude', <any>element);
        })
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    if (opts.status) {
        opts.status.forEach((element) => {
          uri.addQuery('status', <any>element);
        })
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param password The password for the post if it is password protected.
  */
  public async getWpV2PagesById(opts?: { id: string, id2?: number, context?: string, password?: string, }):Promise<Page> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.password !== undefined && opts.password !== null) {
        uri.addQuery('password', <any>opts.password);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param parent The ID for the parent of the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2PagesByIdAutosaves(opts?: { id: string, parent?: number, context?: string, }):Promise<Array<PageRevision>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent !== undefined && opts.parent !== null) {
        uri.addQuery('parent', <any>opts.parent);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 The ID for the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2PagesByParentAutosavesById(opts?: { parent: string, id: string, parent2?: number, id2?: number, context?: string, }):Promise<PageRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param parent2 The ID for the parent of the object.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
  */
  public async getWpV2PagesByParentRevisions(opts?: { parent: string, parent2?: number, context?: string, page?: number, perPage?: number, search?: string, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, }):Promise<Array<PageRevision>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2PagesByParentRevisionsById(opts?: { parent: string, id: string, parent2?: number, id2?: number, context?: string, }):Promise<PageRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param after Limit response to posts published after a given ISO8601 compliant date.
   * @param author Limit result set to posts assigned to specific authors.
   * @param authorExclude Ensure result set excludes posts assigned to specific authors.
   * @param before Limit response to posts published before a given ISO8601 compliant date.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
   * @param slug Limit result set to posts with one or more specific slugs.
   * @param status Limit result set to posts assigned one or more statuses.
   * @param categories Limit result set to all items that have the specified term assigned in the categories taxonomy.
   * @param categoriesExclude Limit result set to all items except those that have the specified term assigned in the categories taxonomy.
   * @param tags Limit result set to all items that have the specified term assigned in the tags taxonomy.
   * @param tagsExclude Limit result set to all items except those that have the specified term assigned in the tags taxonomy.
   * @param sticky Limit result set to items that are sticky.
  */
  public async getWpV2Posts(opts?: { context?: string, page?: number, perPage?: number, search?: string, after?: Date, author?: Array<string>, authorExclude?: Array<string>, before?: Date, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, slug?: Array<string>, status?: Array<string>, categories?: Array<string>, categoriesExclude?: Array<string>, tags?: Array<string>, tagsExclude?: Array<string>, sticky?: boolean, }):Promise<Array<Post>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.after !== undefined && opts.after !== null) {
        uri.addQuery('after', <any>opts.after.toISOString());
    }
    if (opts.author) {
        opts.author.forEach((element) => {
          uri.addQuery('author', <any>element);
        })
    }
    if (opts.authorExclude) {
        opts.authorExclude.forEach((element) => {
          uri.addQuery('author_exclude', <any>element);
        })
    }
    if (opts.before !== undefined && opts.before !== null) {
        uri.addQuery('before', <any>opts.before.toISOString());
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    if (opts.status) {
        opts.status.forEach((element) => {
          uri.addQuery('status', <any>element);
        })
    }
    if (opts.categories) {
        opts.categories.forEach((element) => {
          uri.addQuery('categories', <any>element);
        })
    }
    if (opts.categoriesExclude) {
        opts.categoriesExclude.forEach((element) => {
          uri.addQuery('categories_exclude', <any>element);
        })
    }
    if (opts.tags) {
        opts.tags.forEach((element) => {
          uri.addQuery('tags', <any>element);
        })
    }
    if (opts.tagsExclude) {
        opts.tagsExclude.forEach((element) => {
          uri.addQuery('tags_exclude', <any>element);
        })
    }
    if (opts.sticky !== undefined && opts.sticky !== null) {
        uri.addQuery('sticky', <any>opts.sticky);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param password The password for the post if it is password protected.
  */
  public async getWpV2PostsById(opts?: { id: string, id2?: number, context?: string, password?: string, }):Promise<Post> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.password !== undefined && opts.password !== null) {
        uri.addQuery('password', <any>opts.password);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param parent The ID for the parent of the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2PostsByIdAutosaves(opts?: { id: string, parent?: number, context?: string, }):Promise<Array<PostRevision>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent !== undefined && opts.parent !== null) {
        uri.addQuery('parent', <any>opts.parent);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 The ID for the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2PostsByParentAutosavesById(opts?: { parent: string, id: string, parent2?: number, id2?: number, context?: string, }):Promise<PostRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param parent2 The ID for the parent of the object.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
  */
  public async getWpV2PostsByParentRevisions(opts?: { parent: string, parent2?: number, context?: string, page?: number, perPage?: number, search?: string, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, }):Promise<Array<PostRevision>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param parent 
   * @param id 
   * @param parent2 The ID for the parent of the object.
   * @param id2 Unique identifier for the object.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2PostsByParentRevisionsById(opts?: { parent: string, id: string, parent2?: number, id2?: number, context?: string, }):Promise<PostRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.parent2 !== undefined && opts.parent2 !== null) {
        uri.addQuery('parent', <any>opts.parent2);
    }
    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param type Limit results to items of an object type.
   * @param subtype Limit results to items of one or more object subtypes.
  */
  public async getWpV2Search(opts?: { context?: string, page?: number, perPage?: number, search?: string, type?: string, subtype?: Array<string>, }):Promise<Array<SearchResult>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.type !== undefined && opts.type !== null) {
        uri.addQuery('type', <any>opts.type);
    }
    if (opts.subtype) {
        opts.subtype.forEach((element) => {
          uri.addQuery('subtype', <any>element);
        })
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
  */
  public async getWpV2Settings(opts?: { }):Promise<Array<Settings>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2Statuses(opts?: { context?: string, }):Promise<Array<Status>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param status 
   * @param status2 An alphanumeric identifier for the status.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2StatusesByStatus(opts?: { status: string, status2?: string, context?: string, }):Promise<Status> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.status2 !== undefined && opts.status2 !== null) {
        uri.addQuery('status', <any>opts.status2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by term attribute.
   * @param hideEmpty Whether to hide terms not assigned to any posts.
   * @param post Limit result set to terms assigned to a specific post.
   * @param slug Limit result set to terms with one or more specific slugs.
  */
  public async getWpV2Tags(opts?: { context?: string, page?: number, perPage?: number, search?: string, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, hideEmpty?: boolean, post?: number, slug?: Array<string>, }):Promise<Array<Tag>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.hideEmpty !== undefined && opts.hideEmpty !== null) {
        uri.addQuery('hide_empty', <any>opts.hideEmpty);
    }
    if (opts.post !== undefined && opts.post !== null) {
        uri.addQuery('post', <any>opts.post);
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the term.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2TagsById(opts?: { id: string, id2?: number, context?: string, }):Promise<Tag> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param type Limit results to taxonomies associated with a specific post type.
  */
  public async getWpV2Taxonomies(opts?: { context?: string, type?: string, }):Promise<Array<Taxonomy>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.type !== undefined && opts.type !== null) {
        uri.addQuery('type', <any>opts.type);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param taxonomy 
   * @param taxonomy2 An alphanumeric identifier for the taxonomy.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2TaxonomiesByTaxonomy(opts?: { taxonomy: string, taxonomy2?: string, context?: string, }):Promise<Taxonomy> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.taxonomy2 !== undefined && opts.taxonomy2 !== null) {
        uri.addQuery('taxonomy', <any>opts.taxonomy2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param status Limit result set to themes assigned one or more statuses.
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
  */
  public async getWpV2Themes(opts?: { status: Array<string>, context?: string, page?: number, perPage?: number, search?: string, }):Promise<Array<Theme>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.status) {
        opts.status.forEach((element) => {
          uri.addQuery('status', <any>element);
        })
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2Types(opts?: { context?: string, }):Promise<Array<Type>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param type 
   * @param type2 An alphanumeric identifier for the post type.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2TypesByType(opts?: { type: string, type2?: string, context?: string, }):Promise<Type> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.type2 !== undefined && opts.type2 !== null) {
        uri.addQuery('type', <any>opts.type2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
   * @param page Current page of the collection.
   * @param perPage Maximum number of items to be returned in result set.
   * @param search Limit results to those matching a string.
   * @param exclude Ensure result set excludes specific IDs.
   * @param include Limit result set to specific IDs.
   * @param offset Offset the result set by a specific number of items.
   * @param order Order sort attribute ascending or descending.
   * @param orderby Sort collection by object attribute.
   * @param slug Limit result set to users with one or more specific slugs.
   * @param roles Limit result set to users matching at least one specific role provided. Accepts csv list or single role.
   * @param who Limit result set to users who are considered authors.
  */
  public async getWpV2Users(opts?: { context?: string, page?: number, perPage?: number, search?: string, exclude?: Array<string>, include?: Array<string>, offset?: number, order?: string, orderby?: string, slug?: Array<string>, roles?: Array<string>, who?: string, }):Promise<Array<User>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    if (opts.page !== undefined && opts.page !== null) {
        uri.addQuery('page', <any>opts.page);
    }
    if (opts.perPage !== undefined && opts.perPage !== null) {
        uri.addQuery('per_page', <any>opts.perPage);
    }
    if (opts.search !== undefined && opts.search !== null) {
        uri.addQuery('search', <any>opts.search);
    }
    if (opts.exclude) {
        opts.exclude.forEach((element) => {
          uri.addQuery('exclude', <any>element);
        })
    }
    if (opts.include) {
        opts.include.forEach((element) => {
          uri.addQuery('include', <any>element);
        })
    }
    if (opts.offset !== undefined && opts.offset !== null) {
        uri.addQuery('offset', <any>opts.offset);
    }
    if (opts.order !== undefined && opts.order !== null) {
        uri.addQuery('order', <any>opts.order);
    }
    if (opts.orderby !== undefined && opts.orderby !== null) {
        uri.addQuery('orderby', <any>opts.orderby);
    }
    if (opts.slug) {
        opts.slug.forEach((element) => {
          uri.addQuery('slug', <any>element);
        })
    }
    if (opts.roles) {
        opts.roles.forEach((element) => {
          uri.addQuery('roles', <any>element);
        })
    }
    if (opts.who !== undefined && opts.who !== null) {
        uri.addQuery('who', <any>opts.who);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param id2 Unique identifier for the user.
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2UsersById(opts?: { id: string, id2?: number, context?: string, }):Promise<User> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.id2 !== undefined && opts.id2 !== null) {
        uri.addQuery('id', <any>opts.id2);
    }
    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param context Scope under which the request is made; determines fields present in response.
  */
  public async getWpV2UsersMe(opts?: { context?: string, }):Promise<Array<User>> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    if (opts.context !== undefined && opts.context !== null) {
        uri.addQuery('context', <any>opts.context);
    }
    const options = {
      method: "get",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param template 
  */
  public async postWpV2Blocks(opts?: { date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, template?: string, }):Promise<WpBlock> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param template 
  */
  public async postWpV2BlocksById(opts?: { id2: string, id?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, template?: string, }):Promise<WpBlock> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param parent 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param template 
  */
  public async postWpV2BlocksByIdAutosaves(opts?: { id: string, parent?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, template?: string, }):Promise<WpBlockRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param description 
   * @param name 
   * @param slug 
   * @param parent 
   * @param meta 
  */
  public async postWpV2Categories(opts?: { description?: string, name?: string, slug?: string, parent?: number, meta?: string, }):Promise<Category> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param description 
   * @param name 
   * @param slug 
   * @param parent 
   * @param meta 
  */
  public async postWpV2CategoriesById(opts?: { id2: string, id?: number, description?: string, name?: string, slug?: string, parent?: number, meta?: string, }):Promise<Category> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param author 
   * @param authorEmail 
   * @param authorIp 
   * @param authorName 
   * @param authorUrl 
   * @param authorUserAgent 
   * @param content 
   * @param date 
   * @param dateGmt 
   * @param parent 
   * @param post 
   * @param status 
   * @param meta 
  */
  public async postWpV2Comments(opts?: { author?: number, authorEmail?: string, authorIp?: string, authorName?: string, authorUrl?: string, authorUserAgent?: string, content?: string, date?: Date, dateGmt?: Date, parent?: number, post?: number, status?: string, meta?: string, }):Promise<Comment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param author 
   * @param authorEmail 
   * @param authorIp 
   * @param authorName 
   * @param authorUrl 
   * @param authorUserAgent 
   * @param content 
   * @param date 
   * @param dateGmt 
   * @param parent 
   * @param post 
   * @param status 
   * @param meta 
  */
  public async postWpV2CommentsById(opts?: { id2: string, id?: number, author?: number, authorEmail?: string, authorIp?: string, authorName?: string, authorUrl?: string, authorUserAgent?: string, content?: string, date?: Date, dateGmt?: Date, parent?: number, post?: number, status?: string, meta?: string, }):Promise<Comment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param title 
   * @param author 
   * @param commentStatus 
   * @param pingStatus 
   * @param meta 
   * @param template 
   * @param altText 
   * @param caption 
   * @param description 
   * @param post 
  */
  public async postWpV2Media(opts?: { date?: Date, dateGmt?: Date, slug?: string, status?: string, title?: string, author?: number, commentStatus?: string, pingStatus?: string, meta?: string, template?: string, altText?: string, caption?: string, description?: string, post?: number, }):Promise<Attachment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param title 
   * @param author 
   * @param commentStatus 
   * @param pingStatus 
   * @param meta 
   * @param template 
   * @param altText 
   * @param caption 
   * @param description 
   * @param post 
  */
  public async postWpV2MediaById(opts?: { id2: string, id?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, title?: string, author?: number, commentStatus?: string, pingStatus?: string, meta?: string, template?: string, altText?: string, caption?: string, description?: string, post?: number, }):Promise<Attachment> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param parent 
   * @param title 
   * @param content 
   * @param author 
   * @param excerpt 
   * @param featuredMedia 
   * @param commentStatus 
   * @param pingStatus 
   * @param menuOrder 
   * @param meta 
   * @param template 
  */
  public async postWpV2Pages(opts?: { date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, parent?: number, title?: string, content?: string, author?: number, excerpt?: string, featuredMedia?: number, commentStatus?: string, pingStatus?: string, menuOrder?: number, meta?: string, template?: string, }):Promise<Page> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param parent 
   * @param title 
   * @param content 
   * @param author 
   * @param excerpt 
   * @param featuredMedia 
   * @param commentStatus 
   * @param pingStatus 
   * @param menuOrder 
   * @param meta 
   * @param template 
  */
  public async postWpV2PagesById(opts?: { id2: string, id?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, parent?: number, title?: string, content?: string, author?: number, excerpt?: string, featuredMedia?: number, commentStatus?: string, pingStatus?: string, menuOrder?: number, meta?: string, template?: string, }):Promise<Page> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param parent 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param author 
   * @param excerpt 
   * @param featuredMedia 
   * @param commentStatus 
   * @param pingStatus 
   * @param menuOrder 
   * @param meta 
   * @param template 
  */
  public async postWpV2PagesByIdAutosaves(opts?: { id: string, parent?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, author?: number, excerpt?: string, featuredMedia?: number, commentStatus?: string, pingStatus?: string, menuOrder?: number, meta?: string, template?: string, }):Promise<PageRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param author 
   * @param excerpt 
   * @param featuredMedia 
   * @param commentStatus 
   * @param pingStatus 
   * @param format 
   * @param meta 
   * @param sticky 
   * @param template 
   * @param categories 
   * @param tags 
  */
  public async postWpV2Posts(opts?: { date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, author?: number, excerpt?: string, featuredMedia?: number, commentStatus?: string, pingStatus?: string, format?: string, meta?: string, sticky?: boolean, template?: string, categories?: string, tags?: string, }):Promise<Post> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param author 
   * @param excerpt 
   * @param featuredMedia 
   * @param commentStatus 
   * @param pingStatus 
   * @param format 
   * @param meta 
   * @param sticky 
   * @param template 
   * @param categories 
   * @param tags 
  */
  public async postWpV2PostsById(opts?: { id2: string, id?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, author?: number, excerpt?: string, featuredMedia?: number, commentStatus?: string, pingStatus?: string, format?: string, meta?: string, sticky?: boolean, template?: string, categories?: string, tags?: string, }):Promise<Post> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id 
   * @param parent 
   * @param date 
   * @param dateGmt 
   * @param slug 
   * @param status 
   * @param password 
   * @param title 
   * @param content 
   * @param author 
   * @param excerpt 
   * @param featuredMedia 
   * @param commentStatus 
   * @param pingStatus 
   * @param format 
   * @param meta 
   * @param sticky 
   * @param template 
   * @param categories 
   * @param tags 
  */
  public async postWpV2PostsByIdAutosaves(opts?: { id: string, parent?: number, date?: Date, dateGmt?: Date, slug?: string, status?: string, password?: string, title?: string, content?: string, author?: number, excerpt?: string, featuredMedia?: number, commentStatus?: string, pingStatus?: string, format?: string, meta?: string, sticky?: boolean, template?: string, categories?: string, tags?: string, }):Promise<PostRevision> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param title 
   * @param description 
   * @param url 
   * @param email 
   * @param timezone 
   * @param dateFormat 
   * @param timeFormat 
   * @param startOfWeek 
   * @param language 
   * @param useSmilies 
   * @param defaultCategory 
   * @param defaultPostFormat 
   * @param postsPerPage 
   * @param defaultPingStatus 
   * @param defaultCommentStatus 
  */
  public async postWpV2Settings(opts?: { title?: string, description?: string, url?: string, email?: string, timezone?: string, dateFormat?: string, timeFormat?: string, startOfWeek?: number, language?: string, useSmilies?: boolean, defaultCategory?: number, defaultPostFormat?: string, postsPerPage?: number, defaultPingStatus?: string, defaultCommentStatus?: string, }):Promise<Settings> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param description 
   * @param name 
   * @param slug 
   * @param meta 
  */
  public async postWpV2Tags(opts?: { description?: string, name?: string, slug?: string, meta?: string, }):Promise<Tag> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param description 
   * @param name 
   * @param slug 
   * @param meta 
  */
  public async postWpV2TagsById(opts?: { id2: string, id?: number, description?: string, name?: string, slug?: string, meta?: string, }):Promise<Tag> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param username 
   * @param name 
   * @param firstName 
   * @param lastName 
   * @param email 
   * @param url 
   * @param description 
   * @param locale 
   * @param nickname 
   * @param slug 
   * @param roles 
   * @param password 
   * @param meta 
  */
  public async postWpV2Users(opts?: { username?: string, name?: string, firstName?: string, lastName?: string, email?: string, url?: string, description?: string, locale?: string, nickname?: string, slug?: string, roles?: string, password?: string, meta?: string, }):Promise<User> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param id2 
   * @param id 
   * @param username 
   * @param name 
   * @param firstName 
   * @param lastName 
   * @param email 
   * @param url 
   * @param description 
   * @param locale 
   * @param nickname 
   * @param slug 
   * @param roles 
   * @param password 
   * @param meta 
  */
  public async postWpV2UsersById(opts?: { id2: string, id?: number, username?: string, name?: string, firstName?: string, lastName?: string, email?: string, url?: string, description?: string, locale?: string, nickname?: string, slug?: string, roles?: string, password?: string, meta?: string, }):Promise<User> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }


  /**
   * 
   * @param username 
   * @param name 
   * @param firstName 
   * @param lastName 
   * @param email 
   * @param url 
   * @param description 
   * @param locale 
   * @param nickname 
   * @param slug 
   * @param roles 
   * @param password 
   * @param meta 
  */
  public async postWpV2UsersMe(opts?: { username?: string, name?: string, firstName?: string, lastName?: string, email?: string, url?: string, description?: string, locale?: string, nickname?: string, slug?: string, roles?: string, password?: string, meta?: string, }):Promise<User> {
    if (!opts) {
      opts = {} as any;
    }

    const uri = new URI(`${this.basePath}`);

    const options = {
      method: "post",
      headers: {
        "Content-Type": "application/json",
        "Authorization": `Bearer ${this.rptToken ? this.rptToken : this.token}`
      }
    };

    const response = await fetch(uri.toString(), options);
    return ApiUtils.handleResponse(response);
  }

}